This crate provides functionality to shorten delimited data based on a given configuration.
Here’s a quick example showing its usage:
use squidge::{Config, shorten_line};
let line = "module/submodule/service/lib.rs";
let result = shorten_line(&Config::default(), &line);
let expected = vec!["m", "s", "s", "lib.rs"];
assert_eq!(result, expected);Structs
- Config
- Represents the config used by squidge.
Functions
- shorten_
line - Shortens a line based on the provided configuration and returns the components as a
Vec<String>.